@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use Moo;
 use strictures 2;
@@ -599,7 +599,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
@@ -610,9 +610,9 @@ version 0.0600
 =head1 DESCRIPTION
 
 C<Music::CreatingRhythms> provides the combinatorial algorithms
-described in the book, "Creating Rhythms", by Hollos. These algorithms
-are ported directly from the C, and are pretty fast. Please see the
-links below for more information.
+described in the book, "Creating Rhythms", by Hollos. Many of these
+algorithms are ported directly from the C, and are pretty fast. Please
+see the links below for more information.
 
 NB: Arguments are sometimes switched between book and software.
 
@@ -827,9 +827,9 @@ Invert a section of a B<parts> binary sequence at B<n>.
 Examples:
 
     $parts = [qw(1 0 1 0 0)];
-    $got = $mcr->invert_at(0, $parts); # 0 1 0 1 1
-    $got = $mcr->invert_at(1, $parts); # 1 1 0 1 1
-    $got = $mcr->invert_at(2, $parts); # 1 0 0 1 1
+    $got = $mcr->invert_at(0, $parts); # [0,1,0,1,1]
+    $got = $mcr->invert_at(1, $parts); # [1,1,0,1,1]
+    $got = $mcr->invert_at(2, $parts); # [1,0,0,1,1]
 
 =head2 neck
 
@@ -972,10 +972,10 @@ Reverse a section of a B<parts> sequence at B<n>.
 Examples:
 
   $parts = [qw(1 0 1 0 0)];
-  $got = $mcr->reverse_at(0, $parts); # 0 0 1 0 1
-  $got = $mcr->reverse_at(1, $parts); # 1 0 0 1 0
-  $got = $mcr->reverse_at(2, $parts); # 1 0 0 0 1
-  $got = $mcr->reverse_at(3, $parts); # 1 0 1 0 0
+  $got = $mcr->reverse_at(0, $parts); # [0,0,1,0,1]
+  $got = $mcr->reverse_at(1, $parts); # [1,0,0,1,0]
+  $got = $mcr->reverse_at(2, $parts); # [1,0,0,0,1]
+  $got = $mcr->reverse_at(3, $parts); # [1,0,1,0,0]
 
 =head2 rotate_n
 
@@ -986,12 +986,12 @@ Rotate a necklace of the given B<parts>, B<n> times.
 Examples:
 
   $parts = [qw(1 0 1 0 0)];
-  $got = $mcr->rotate_n(0, $parts); # 1 0 1 0 0
-  $got = $mcr->rotate_n(1, $parts); # 0 1 0 1 0
-  $got = $mcr->rotate_n(2, $parts); # 0 0 1 0 1
-  $got = $mcr->rotate_n(3, $parts); # 1 0 0 1 0
-  $got = $mcr->rotate_n(4, $parts); # 0 1 0 0 1
-  $got = $mcr->rotate_n(5, $parts); # 1 0 1 0 0
+  $got = $mcr->rotate_n(0, $parts); # [1,0,1,0,0]
+  $got = $mcr->rotate_n(1, $parts); # [0,1,0,1,0]
+  $got = $mcr->rotate_n(2, $parts); # [0,0,1,0,1]
+  $got = $mcr->rotate_n(3, $parts); # [1,0,0,1,0]
+  $got = $mcr->rotate_n(4, $parts); # [0,1,0,0,1]
+  $got = $mcr->rotate_n(5, $parts); # [1,0,1,0,0]
 
 =head1 SEE ALSO
 
